@@ -486,6 +486,13 @@ class ManagedIdentitiesServiceClient(metaclass=ManagedIdentitiesServiceClientMet
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import managedidentities_v1
 
             def sample_create_microsoft_ad_domain():
@@ -496,7 +503,7 @@ class ManagedIdentitiesServiceClient(metaclass=ManagedIdentitiesServiceClientMet
                 domain = managedidentities_v1.Domain()
                 domain.name = "name_value"
                 domain.reserved_ip_range = "reserved_ip_range_value"
-                domain.locations = ['locations_value_1', 'locations_value_2']
+                domain.locations = ['locations_value1', 'locations_value2']
 
                 request = managedidentities_v1.CreateMicrosoftAdDomainRequest(
                     parent="parent_value",
@@ -639,6 +646,13 @@ class ManagedIdentitiesServiceClient(metaclass=ManagedIdentitiesServiceClientMet
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import managedidentities_v1
 
             def sample_reset_admin_password():
@@ -736,6 +750,13 @@ class ManagedIdentitiesServiceClient(metaclass=ManagedIdentitiesServiceClientMet
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import managedidentities_v1
 
             def sample_list_domains():
@@ -844,6 +865,13 @@ class ManagedIdentitiesServiceClient(metaclass=ManagedIdentitiesServiceClientMet
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import managedidentities_v1
 
             def sample_get_domain():
@@ -940,6 +968,13 @@ class ManagedIdentitiesServiceClient(metaclass=ManagedIdentitiesServiceClientMet
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import managedidentities_v1
 
             def sample_update_domain():
@@ -950,7 +985,7 @@ class ManagedIdentitiesServiceClient(metaclass=ManagedIdentitiesServiceClientMet
                 domain = managedidentities_v1.Domain()
                 domain.name = "name_value"
                 domain.reserved_ip_range = "reserved_ip_range_value"
-                domain.locations = ['locations_value_1', 'locations_value_2']
+                domain.locations = ['locations_value1', 'locations_value2']
 
                 request = managedidentities_v1.UpdateDomainRequest(
                     domain=domain,
@@ -1072,6 +1107,13 @@ class ManagedIdentitiesServiceClient(metaclass=ManagedIdentitiesServiceClientMet
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import managedidentities_v1
 
             def sample_delete_domain():
@@ -1190,6 +1232,13 @@ class ManagedIdentitiesServiceClient(metaclass=ManagedIdentitiesServiceClientMet
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import managedidentities_v1
 
             def sample_attach_trust():
@@ -1201,7 +1250,7 @@ class ManagedIdentitiesServiceClient(metaclass=ManagedIdentitiesServiceClientMet
                 trust.target_domain_name = "target_domain_name_value"
                 trust.trust_type = "EXTERNAL"
                 trust.trust_direction = "BIDIRECTIONAL"
-                trust.target_dns_ip_addresses = ['target_dns_ip_addresses_value_1', 'target_dns_ip_addresses_value_2']
+                trust.target_dns_ip_addresses = ['target_dns_ip_addresses_value1', 'target_dns_ip_addresses_value2']
                 trust.trust_handshake_secret = "trust_handshake_secret_value"
 
                 request = managedidentities_v1.AttachTrustRequest(
@@ -1318,6 +1367,13 @@ class ManagedIdentitiesServiceClient(metaclass=ManagedIdentitiesServiceClientMet
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import managedidentities_v1
 
             def sample_reconfigure_trust():
@@ -1328,7 +1384,7 @@ class ManagedIdentitiesServiceClient(metaclass=ManagedIdentitiesServiceClientMet
                 request = managedidentities_v1.ReconfigureTrustRequest(
                     name="name_value",
                     target_domain_name="target_domain_name_value",
-                    target_dns_ip_addresses=['target_dns_ip_addresses_value_1', 'target_dns_ip_addresses_value_2'],
+                    target_dns_ip_addresses=['target_dns_ip_addresses_value1', 'target_dns_ip_addresses_value2'],
                 )
 
                 # Make the request
@@ -1452,6 +1508,13 @@ class ManagedIdentitiesServiceClient(metaclass=ManagedIdentitiesServiceClientMet
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import managedidentities_v1
 
             def sample_detach_trust():
@@ -1463,7 +1526,7 @@ class ManagedIdentitiesServiceClient(metaclass=ManagedIdentitiesServiceClientMet
                 trust.target_domain_name = "target_domain_name_value"
                 trust.trust_type = "EXTERNAL"
                 trust.trust_direction = "BIDIRECTIONAL"
-                trust.target_dns_ip_addresses = ['target_dns_ip_addresses_value_1', 'target_dns_ip_addresses_value_2']
+                trust.target_dns_ip_addresses = ['target_dns_ip_addresses_value1', 'target_dns_ip_addresses_value2']
                 trust.trust_handshake_secret = "trust_handshake_secret_value"
 
                 request = managedidentities_v1.DetachTrustRequest(
@@ -1583,6 +1646,13 @@ class ManagedIdentitiesServiceClient(metaclass=ManagedIdentitiesServiceClientMet
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import managedidentities_v1
 
             def sample_validate_trust():
@@ -1594,7 +1664,7 @@ class ManagedIdentitiesServiceClient(metaclass=ManagedIdentitiesServiceClientMet
                 trust.target_domain_name = "target_domain_name_value"
                 trust.trust_type = "EXTERNAL"
                 trust.trust_direction = "BIDIRECTIONAL"
-                trust.target_dns_ip_addresses = ['target_dns_ip_addresses_value_1', 'target_dns_ip_addresses_value_2']
+                trust.target_dns_ip_addresses = ['target_dns_ip_addresses_value1', 'target_dns_ip_addresses_value2']
                 trust.trust_handshake_secret = "trust_handshake_secret_value"
 
                 request = managedidentities_v1.ValidateTrustRequest(
