@@ -13,12 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 import proto  # type: ignore
 
 from google.cloud.managedidentities_v1.types import resource
-from google.protobuf import field_mask_pb2  # type: ignore
-from google.protobuf import timestamp_pb2  # type: ignore
-
 
 __protobuf__ = proto.module(
     package="google.cloud.managedidentities.v1",
@@ -67,12 +66,32 @@ class OpMetadata(proto.Message):
             operation.
     """
 
-    create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    target = proto.Field(proto.STRING, number=3,)
-    verb = proto.Field(proto.STRING, number=4,)
-    requested_cancellation = proto.Field(proto.BOOL, number=5,)
-    api_version = proto.Field(proto.STRING, number=6,)
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    target = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    verb = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    requested_cancellation = proto.Field(
+        proto.BOOL,
+        number=5,
+    )
+    api_version = proto.Field(
+        proto.STRING,
+        number=6,
+    )
 
 
 class CreateMicrosoftAdDomainRequest(proto.Message):
@@ -102,9 +121,19 @@ class CreateMicrosoftAdDomainRequest(proto.Message):
             Required. A Managed Identity domain resource.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    domain_name = proto.Field(proto.STRING, number=2,)
-    domain = proto.Field(proto.MESSAGE, number=3, message=resource.Domain,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    domain_name = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    domain = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=resource.Domain,
+    )
 
 
 class ResetAdminPasswordRequest(proto.Message):
@@ -117,7 +146,10 @@ class ResetAdminPasswordRequest(proto.Message):
             ``projects/{project_id}/locations/global/domains/{domain_name}``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ResetAdminPasswordResponse(proto.Message):
@@ -131,7 +163,10 @@ class ResetAdminPasswordResponse(proto.Message):
             more information.
     """
 
-    password = proto.Field(proto.STRING, number=1,)
+    password = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListDomainsRequest(proto.Message):
@@ -162,11 +197,26 @@ class ListDomainsRequest(proto.Message):
             for more information.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListDomainsResponse(proto.Message):
@@ -190,9 +240,19 @@ class ListDomainsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    domains = proto.RepeatedField(proto.MESSAGE, number=1, message=resource.Domain,)
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=3,)
+    domains = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=resource.Domain,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
 
 
 class GetDomainRequest(proto.Message):
@@ -205,7 +265,10 @@ class GetDomainRequest(proto.Message):
             ``projects/{project_id}/locations/global/domains/{domain_name}``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class UpdateDomainRequest(proto.Message):
@@ -228,9 +291,15 @@ class UpdateDomainRequest(proto.Message):
     """
 
     update_mask = proto.Field(
-        proto.MESSAGE, number=1, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=1,
+        message=field_mask_pb2.FieldMask,
+    )
+    domain = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=resource.Domain,
     )
-    domain = proto.Field(proto.MESSAGE, number=2, message=resource.Domain,)
 
 
 class DeleteDomainRequest(proto.Message):
@@ -243,7 +312,10 @@ class DeleteDomainRequest(proto.Message):
             ``projects/{project_id}/locations/global/domains/{domain_name}``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class AttachTrustRequest(proto.Message):
@@ -259,8 +331,15 @@ class AttachTrustRequest(proto.Message):
             Required. The domain trust resource.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    trust = proto.Field(proto.MESSAGE, number=2, message=resource.Trust,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    trust = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=resource.Trust,
+    )
 
 
 class ReconfigureTrustRequest(proto.Message):
@@ -281,9 +360,18 @@ class ReconfigureTrustRequest(proto.Message):
             trust.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    target_domain_name = proto.Field(proto.STRING, number=2,)
-    target_dns_ip_addresses = proto.RepeatedField(proto.STRING, number=3,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    target_domain_name = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    target_dns_ip_addresses = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
 
 
 class DetachTrustRequest(proto.Message):
@@ -300,8 +388,15 @@ class DetachTrustRequest(proto.Message):
             removed.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    trust = proto.Field(proto.MESSAGE, number=2, message=resource.Trust,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    trust = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=resource.Trust,
+    )
 
 
 class ValidateTrustRequest(proto.Message):
@@ -318,8 +413,15 @@ class ValidateTrustRequest(proto.Message):
             state for.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    trust = proto.Field(proto.MESSAGE, number=2, message=resource.Trust,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    trust = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=resource.Trust,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
